; *********************************************************** ;
;                           BLINKY                            ;
;       make a LED blink every second using interrupts        ;
;       from Timer0                                           ;
;                                                             ;
;       INFO0064 - Embedded Systems                           ;
;       Author: Kevin Hogan                                   ;
;                                                             ;
; *********************************************************** ;


    #include 	"config.inc"
    #DEFINE		value_counter	0x4C    ; (= 76) value determined during the Exercice Session 2, and used to obtain the required delay

; Set the first variable address in the RAM to 0x00
	cblock	0x00
	endc

; That is where the MCU will start executing the program (0x00)
	org 	0x00
	nop
	goto    start           ; jump to the beginning of the code

; interrupt vector: if an interrupt occurs, the MCU jumps to this address (0x08)
; we need to jump to the code that will handle the interrupt request
	org 	0x08
	goto 	interrupt_vector


;BEGINNING OF THE PROGRAM
start:
	call	initialisation      ; initialisation routine configuring the MCU
	goto	main_loop           ; main loop

;INITIALISATION
initialisation:

    ;configuration of the GPIO
    clrf    TRISB               ; All pins of PORTB are output
    movlw   b'00000001'
    movwf   LATB                ; RB0 = 1 while RB1..7 = 0;

    ;configuration of Timer0
    ; Timer0 ON - 16 bits mode - NO prescaling
	movlw	b'10001000'
	movwf	T0CON               ; configure Timer0 (cf. datasheet SFR T0CON)

    ;set the counter
	movlw	value_counter
	movwf	counter

    ;enable interrupts
	bsf		INTCON , TMR0IE     ; enable interrupt for Timer0
	bsf		INTCON , GIE        ; enable interrupts

	return


	cblock
	counter	:	1
	endc

;INTERRUPT ROUTINE
; Here we have to determine what triggered the interrupt request
interrupt_vector:

;Timer0 test
test_int_Timer_0:
	btfss	INTCON , TMR0IE     ; Is Timer0 Interrupt Enable bit set?
	goto	other_test_int      ; skip if yes

	btfsc	INTCON , TMR0IF     ; Is Timer0 Interrupt Flag bit set?
	call	interrupt_Timer_0   ; skip if no

;Other tests (if any)
other_test_int:

end_of_test_int:
	retfie 	1                   ; return from the interrupt routine

;TIMER0 INTERRUPT ROUTINE
; we have to wait for value_counter interrupts before changing the value of RB0
; (value_counter has been determined during Exercice Session 2)
interrupt_Timer_0:
	bcf		INTCON , TMR0IF		; Clear the Interrupt Flag!
	decfsz	counter , f         ; if counter = 0 then the next instruction is skipped else counter--
	return

	movlw	0x01
	xorwf	LATB , f            ; RB0 = !RB0

	movlw	value_counter
	movwf	counter             ; reset the value of the counter

	return

;MAIN LOOP
; nothing to do but wait for interrupts
main_loop:
	nop
	goto	main_loop

	END