;****************************************************************************************;
;                                                                                        ;
; Set the configuration bits of the MCU                                                  ;
; Those bits are used to select various device configurations.                           ;
; Go check the include file "P18F4620.inc" and the datasheet for more information        ;
; You can find the include file in the "mpasmx" folder (MPASM Assembler)                 ;
;                                                                                        ;
;****************************************************************************************;

    #include <P18F4620.INC>     ; Include file

	CONFIG OSC      = HS        ; External oscillator block, port function on RA6 and RA7
	CONFIG FCMEN    = OFF       ; Fail-Safe Clock Monitor Enable bit

	CONFIG IESO     = OFF       ; Internal/External Oscillator Switchover bit
	CONFIG PWRT     = ON        ; Power-up Timer Enable bit
	CONFIG BOREN    = OFF       ; Brown-out Reset Enable bits
	CONFIG BORV     = 3         ; Brown-out Voltage bits
	CONFIG MCLRE    = ON        ; MCLR Pin Enable bit
	CONFIG LPT1OSC  = OFF       ; Timer1 configured for higher power operation
	CONFIG PBADEN   = OFF       ; PORTB <4:0> pins are configured as digital I/O on Reset
	CONFIG CCP2MX   = PORTC     ; CCP2 input/output is multiplexed with RC1
	CONFIG STVREN   = ON        ; Stack Full/Underflow Reset Enable bit
	CONFIG LVP      = OFF       ; Single-Supply ICSP Enable bit         <---- to have RB5 as an IO
	CONFIG XINST    = OFF       ; Extended Instruction Set Enable bit
	CONFIG DEBUG    = OFF       ; Background Debugger Enable bit
	CONFIG CP0      = OFF       ; Code Protection bit Block 0
	CONFIG CP1      = OFF       ; Code Protection bit Block 1
	CONFIG CP2      = OFF       ; Code Protection bit Block 2
	CONFIG CP3      = OFF       ; Code Protection bit Block 3
	CONFIG CPB      = OFF       ; Boot Block Code Protection bit
	CONFIG CPD      = OFF       ; Data EEPROM Code Protection bit
	CONFIG WRT0     = OFF       ; Write Protection bit Block 0
	CONFIG WRT1     = OFF       ; Write Protection bit Block 1
	CONFIG WRT2     = OFF       ; Write Protection bit Block 2
	CONFIG WRT3     = OFF       ; Write Protection bit Block 3
	CONFIG WRTB     = OFF       ; Boot Block Write Protection bit
	CONFIG WRTC     = OFF       ; Configuration Register Write Protection bit
	CONFIG WRTD     = OFF       ; Data EEPROM Write Protection bit
	CONFIG EBTR0    = OFF       ; Table Read Protection bit Block 0
	CONFIG EBTR1    = OFF       ; Table Read Protection bit Block 1
	CONFIG EBTR2    = OFF       ; Table Read Protection bit Block 2
	CONFIG EBTR3    = OFF       ; Table Read Protection bit Block 3
	CONFIG EBTRB    = OFF       ; Boot Block Table Read Protection

	CONFIG WDT      = OFF       ; Watchdog Timer Enable bit
	CONFIG WDTPS    = 1


;==========================================================================
;   IMPORTANT: For the PIC18 devices, the __CONFIG directive has been
;              superseded by the CONFIG directive.  The following settings
;              are available for this device.
;
;   Oscillator Selection:
;     OSC = LP             LP
;     OSC = XT             XT
;     OSC = HS             HS
;     OSC = RC             RC
;     OSC = EC             EC-OSC2 as Clock Out
;     OSC = ECIO6          EC-OSC2 as RA6
;     OSC = HSPLL          HS-PLL Enabled
;     OSC = RCIO6          RC-OSC2 as RA6
;     OSC = INTIO67        INTRC-OSC2 as RA6, OSC1 as RA7
;     OSC = INTIO7         INTRC-OSC2 as Clock Out, OSC1 as RA7
;
;   Fail-Safe Clock Monitor:
;     FCMEN = OFF          Disabled
;     FCMEN = ON           Enabled
;
;   Internal External Osc. Switch Over:
;     IESO = OFF           Disabled
;     IESO = ON            Enabled
;
;   Power-up Timer:
;     PWRT = ON            Enabled
;     PWRT = OFF           Disabled
;
;   Brown-out Reset:
;     BOREN = OFF          Disabled
;     BOREN = ON           SBOREN Enabled
;     BOREN = NOSLP        Enabled except Sleep, SBOREN Disabled
;     BOREN = SBORDIS      Enabled, SBOREN Disabled
;
;   Brown-out Voltage:
;     BORV = 0             Maximum setting
;     BORV = 1
;     BORV = 2
;     BORV = 3             Minimum setting
;
;   Watchdog Timer:
;     WDT = OFF            Disabled
;     WDT = ON             Enabled
;
;   Watchdog Postscaler:
;     WDTPS = 1            1:1
;     WDTPS = 2            1:2
;     WDTPS = 4            1:4
;     WDTPS = 8            1:8
;     WDTPS = 16           1:16
;     WDTPS = 32           1:32
;     WDTPS = 64           1:64
;     WDTPS = 128          1:128
;     WDTPS = 256          1:256
;     WDTPS = 512          1:512
;     WDTPS = 1024         1:1024
;     WDTPS = 2048         1:2048
;     WDTPS = 4096         1:4096
;     WDTPS = 8192         1:8192
;     WDTPS = 16384        1:16384
;     WDTPS = 32768        1:32768
;
;   MCLR Enable:
;     MCLRE = OFF          Disabled
;     MCLRE = ON           Enabled
;
;   T1 Oscillator Enable:
;     LPT1OSC = OFF        Disabled
;     LPT1OSC = ON         Enabled
;
;   PORTB A/D Enable:
;     PBADEN = OFF         PORTB<4:0> digital on Reset
;     PBADEN = ON          PORTB<4:0> analog on Reset
;
;   CCP2 MUX:
;     CCP2MX = PORTBE      Multiplexed with RB3
;     CCP2MX = PORTC       Multiplexed with RC1
;
;   Stack Overflow Reset:
;     STVREN = OFF         Disabled
;     STVREN = ON          Enabled
;
;   Low Voltage ICSP:
;     LVP = OFF            Disabled
;     LVP = ON             Enabled
;
;   XINST Enable:
;     XINST = OFF          Disabled
;     XINST = ON           Enabled
;
;   Background Debugger Enable:
;     DEBUG = ON           Enabled
;     DEBUG = OFF          Disabled
;
;   Code Protection Block 0:
;     CP0 = ON             Enabled
;     CP0 = OFF            Disabled
;
;   Code Protection Block 1:
;     CP1 = ON             Enabled
;     CP1 = OFF            Disabled
;
;   Code Protection Block 2:
;     CP2 = ON             Enabled
;     CP2 = OFF            Disabled
;
;   Code Protection Block 3:
;     CP3 = ON             Enabled
;     CP3 = OFF            Disabled
;
;   Boot Block Code Protection:
;     CPB = ON             Enabled
;     CPB = OFF            Disabled
;
;   Data EEPROM Code Protection:
;     CPD = ON             Enabled
;     CPD = OFF            Disabled
;
;   Write Protection Block 0:
;     WRT0 = ON            Enabled
;     WRT0 = OFF           Disabled
;
;   Write Protection Block 1:
;     WRT1 = ON            Enabled
;     WRT1 = OFF           Disabled
;
;   Write Protection Block 2:
;     WRT2 = ON            Enabled
;     WRT2 = OFF           Disabled
;
;   Write Protection Block 3:
;     WRT3 = ON            Enabled
;     WRT3 = OFF           Disabled
;
;   Boot Block Write Protection:
;     WRTB = ON            Enabled
;     WRTB = OFF           Disabled
;
;   Configuration Register Write Protection:
;     WRTC = ON            Enabled
;     WRTC = OFF           Disabled
;
;   Data EEPROM Write Protection:
;     WRTD = ON            Enabled
;     WRTD = OFF           Disabled
;
;   Table Read Protection Block 0:
;     EBTR0 = ON           Enabled
;     EBTR0 = OFF          Disabled
;
;   Table Read Protection Block 1:
;     EBTR1 = ON           Enabled
;     EBTR1 = OFF          Disabled
;
;   Table Read Protection Block 2:
;     EBTR2 = ON           Enabled
;     EBTR2 = OFF          Disabled
;
;   Table Read Protection Block 3:
;     EBTR3 = ON           Enabled
;     EBTR3 = OFF          Disabled
;
;   Boot Block Table Read Protection:
;     EBTRB = ON           Enabled
;     EBTRB = OFF          Disabled